@@ -2,7 +2,7 @@ use strict;
 use warnings;
 
 package Message::String;
-our $VERSION = '0.1.0'; # VERSION
+our $VERSION = '0.1.1'; # VERSION
 # ABSTRACT: A pragma to declare and organise messaging.
 use Clone           ( 'clone' );
 use DateTime        ();
@@ -1145,7 +1145,7 @@ Message::String - A pragma to declare and organise messaging.
 
 =head1 VERSION
 
-version 0.1.0
+version 0.1.1
 
 =head1 SYNOPSIS
 
@@ -2021,6 +2021,51 @@ change it back when you're done.
     MESSAGE_ID->_type_id($type_str, $bool);
     MESSAGE_ID->_type_id($bool);
 
+=head1 REPOSITORY
+
+=over 2
+
+=item * L<https://github.com/cpanic/Message-String>
+
+=item * L<http://search.cpan.org/dist/Message-String/lib/Message/String.pm>
+
+=back
+
+=head1 BUGS
+
+Please report any bugs or feature requests to C<bug-message-string at rt.cpan.org>, or through
+the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Message-String>.  I will be notified, and then you'll
+automatically be notified of progress on your bug as I make changes.
+
+=head1 SUPPORT
+
+You can find documentation for this module with the perldoc command.
+
+    perldoc Message::String
+
+
+You can also look for information at:
+
+=over 4
+
+=item * RT: CPAN's request tracker (report bugs here)
+
+L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Message-String>
+
+=item * AnnoCPAN: Annotated CPAN documentation
+
+L<http://annocpan.org/dist/Message-String>
+
+=item * CPAN Ratings
+
+L<http://cpanratings.perl.org/d/Message-String>
+
+=item * Search CPAN
+
+L<http://search.cpan.org/dist/Message-String/>
+
+=back
+
 =head1 ACKNOWLEDGEMENTS
 
 Standing as we all do from time to time on the shoulders of giants:
